Model: input form

# Model of stellar population synthesis of the Galaxy

## Catalogue simulation without kinematics, Johnson-Cousins photometric system

The resulting parameter file 1376235131.430670.par has been built; a message will be sent to address keflavich@gmail.com when the simulation is complete
new access to the model form:

### Summary of the parameters you supplied

A mail will be sent to address: keflavich@gmail.com when the simulation is completed
The name of the file containing the result of the simulation will be: 1376235131.430670.resu

#### Field of view:

distance step mode: progressive
small field
Longitude: 173
Latitude: 3
solid angle: 0.01

#### Extinction:

diffuse absorption: 0.700 mag/kpc
no discrete clouds

parameter | min | max | step
--- | --- | --- | ---
Absolute V magnitude | -7.00 | 20.00 | 0.50
Spectral type | 1 | 9.5 | 0.1
Luminosity class | 1 | 7 | 1.00
Population-age | 1 | 10 | 1
[Fe/H] | -4.20 | 1.50 | 0.30
Distance | 0.000000 | 50.000000 | 2.00
V app. magnitude | -10 | 18.00 | 1
B-V | -99.00 | 99.00 | 10.00
U-B | -99.00 | 99.00 | 10.00
V-I | -99.00 | 99.00 | 10.00
V-K | -99.00 | 99.00 | 10.00
LogTeff | 3.00 | 6.00 | 0.10

#### Errors:

error mode:parabolic error = A + B*m + C*m2
photometric errors:

photometric band | A | B | C
--- | --- | --- | ---
V | 0.000000 | 0.000000 | 0.000000
B | 0.000000 | 0.000000 | 0.000000
U | 0.000000 | 0.000000 | 0.000000
R | 0.000000 | 0.000000 | 0.000000
I | 0.000000 | 0.000000 | 0.000000
J | 0.000000 | 0.000000 | 0.000000
H | 0.000000 | 0.000000 | 0.000000
K | 0.000000 | 0.000000 | 0.000000
L | 0.000000 | 0.000000 | 0.000000